@@ -3,6 +3,7 @@ import contextlib
 import inspect as stdlib_inspect
 from unittest.mock import patch
 
+from sqlalchemy import AssertionPool
 from sqlalchemy import Column
 from sqlalchemy import create_engine
 from sqlalchemy import delete
@@ -11,7 +12,11 @@ from sqlalchemy import exc
 from sqlalchemy import func
 from sqlalchemy import inspect
 from sqlalchemy import Integer
+from sqlalchemy import NullPool
+from sqlalchemy import QueuePool
 from sqlalchemy import select
+from sqlalchemy import SingletonThreadPool
+from sqlalchemy import StaticPool
 from sqlalchemy import String
 from sqlalchemy import Table
 from sqlalchemy import testing
@@ -520,6 +525,77 @@ class AsyncEngineTest(EngineFixture):
 
         eq_(isolation_level, "SERIALIZABLE")
 
+    @testing.combinations(
+        (
+            AsyncAdaptedQueuePool,
+            True,
+        ),
+        (
+            QueuePool,
+            False,
+        ),
+        (NullPool, True),
+        (SingletonThreadPool, False),
+        (StaticPool, True),
+        (AssertionPool, True),
+        argnames="pool_cls,should_work",
+    )
+    @testing.variation("instantiate", [True, False])
+    @async_test
+    async def test_pool_classes(
+        self, async_testing_engine, pool_cls, instantiate, should_work
+    ):
+        """test #8771"""
+        if instantiate:
+            if pool_cls in (QueuePool, AsyncAdaptedQueuePool):
+                pool = pool_cls(creator=testing.db.pool._creator, timeout=10)
+            else:
+                pool = pool_cls(
+                    creator=testing.db.pool._creator,
+                )
+
+            options = {"pool": pool}
+        else:
+            if pool_cls in (QueuePool, AsyncAdaptedQueuePool):
+                options = {"poolclass": pool_cls, "pool_timeout": 10}
+            else:
+                options = {"poolclass": pool_cls}
+
+        if not should_work:
+            with expect_raises_message(
+                exc.ArgumentError,
+                f"Pool class {pool_cls.__name__} "
+                "cannot be used with asyncio engine",
+            ):
+                async_testing_engine(options=options)
+            return
+
+        e = async_testing_engine(options=options)
+
+        if pool_cls is AssertionPool:
+            async with e.connect() as conn:
+                result = await conn.scalar(select(1))
+                eq_(result, 1)
+            return
+
+        async def go():
+            async with e.connect() as conn:
+                result = await conn.scalar(select(1))
+                eq_(result, 1)
+                return result
+
+        eq_(await asyncio.gather(*[go() for i in range(10)]), [1] * 10)
+
+    def test_cant_use_async_pool_w_create_engine(self):
+        """supplemental test for #8771"""
+
+        with expect_raises_message(
+            exc.ArgumentError,
+            "Pool class AsyncAdaptedQueuePool "
+            "cannot be used with non-asyncio engine",
+        ):
+            create_engine("sqlite://", poolclass=AsyncAdaptedQueuePool)
+
     @testing.requires.queue_pool
     @async_test
     async def test_dispose(self, async_engine):
@@ -785,6 +861,27 @@ class AsyncEngineTest(EngineFixture):
         finally:
             await greenlet_spawn(conn.close)
 
+    @testing.combinations("stream", "stream_scalars", argnames="method")
+    @async_test
+    async def test_server_side_required_for_scalars(
+        self, async_engine, method
+    ):
+        with mock.patch.object(
+            async_engine.dialect, "supports_server_side_cursors", False
+        ):
+            async with async_engine.connect() as c:
+                with expect_raises_message(
+                    exc.InvalidRequestError,
+                    "Cant use `stream` or `stream_scalars` with the current "
+                    "dialect since it does not support server side cursors.",
+                ):
+                    if method == "stream":
+                        await c.stream(select(1))
+                    elif method == "stream_scalars":
+                        await c.stream_scalars(select(1))
+                    else:
+                        testing.fail(method)
+
 
 class AsyncCreatePoolTest(fixtures.TestBase):
     @config.fixture
@@ -857,44 +954,44 @@ class AsyncEventTest(EngineFixture):
         ):
             event.listen(async_engine, "checkout", mock.Mock())
 
+    def select1(self, engine):
+        if engine.dialect.name == "oracle":
+            return "select 1 from dual"
+        else:
+            return "select 1"
+
     @async_test
     async def test_sync_before_cursor_execute_engine(self, async_engine):
         canary = mock.Mock()
 
         event.listen(async_engine.sync_engine, "before_cursor_execute", canary)
 
+        s1 = self.select1(async_engine)
         async with async_engine.connect() as conn:
             sync_conn = conn.sync_connection
-            await conn.execute(text("select 1"))
+            await conn.execute(text(s1))
 
         eq_(
             canary.mock_calls,
-            [
-                mock.call(
-                    sync_conn, mock.ANY, "select 1", mock.ANY, mock.ANY, False
-                )
-            ],
+            [mock.call(sync_conn, mock.ANY, s1, mock.ANY, mock.ANY, False)],
         )
 
     @async_test
     async def test_sync_before_cursor_execute_connection(self, async_engine):
         canary = mock.Mock()
 
+        s1 = self.select1(async_engine)
         async with async_engine.connect() as conn:
             sync_conn = conn.sync_connection
 
             event.listen(
                 async_engine.sync_engine, "before_cursor_execute", canary
             )
-            await conn.execute(text("select 1"))
+            await conn.execute(text(s1))
 
         eq_(
             canary.mock_calls,
-            [
-                mock.call(
-                    sync_conn, mock.ANY, "select 1", mock.ANY, mock.ANY, False
-                )
-            ],
+            [mock.call(sync_conn, mock.ANY, s1, mock.ANY, mock.ANY, False)],
         )
 
     @async_test
@@ -932,6 +1029,9 @@ class AsyncInspection(EngineFixture):
 
 
 class AsyncResultTest(EngineFixture):
+    __backend__ = True
+    __requires__ = ("server_side_cursors", "async_dialect")
+
     @async_test
     async def test_no_ss_cursor_w_execute(self, async_engine):
         users = self.tables.users
@@ -1259,7 +1359,13 @@ class TextSyncDBAPI(fixtures.TestBase):
     def async_engine(self):
         engine = create_engine("sqlite:///:memory:", future=True)
         engine.dialect.is_async = True
-        return _async_engine.AsyncEngine(engine)
+        engine.dialect.supports_server_side_cursors = True
+        with mock.patch.object(
+            engine.dialect.execution_ctx_cls,
+            "create_server_side_cursor",
+            engine.dialect.execution_ctx_cls.create_default_cursor,
+        ):
+            yield _async_engine.AsyncEngine(engine)
 
     @async_test
     @combinations(
@@ -1396,3 +1502,23 @@ class AsyncProxyTest(EngineFixture, fixtures.TestBase):
 
         async_t2 = async_conn.get_transaction()
         is_(async_t1, async_t2)
+
+
+class PoolRegenTest(EngineFixture):
+    @testing.requires.queue_pool
+    @async_test
+    @testing.variation("do_dispose", [True, False])
+    async def test_gather_after_dispose(self, testing_engine, do_dispose):
+        engine = testing_engine(
+            asyncio=True, options=dict(pool_size=10, max_overflow=10)
+        )
+
+        async def thing(engine):
+            async with engine.connect() as conn:
+                await conn.exec_driver_sql("select 1")
+
+        if do_dispose:
+            await engine.dispose()
+
+        tasks = [thing(engine) for _ in range(10)]
+        await asyncio.gather(*tasks)
