@@ -472,7 +472,6 @@ class InsertExecTest(fixtures.TablesTest):
 
 
 class TableInsertTest(fixtures.TablesTest):
-
     """test for consistent insert behavior across dialects
     regarding the inline() method, values() method, lower-case 't' tables.
 
@@ -788,7 +787,8 @@ class InsertManyValuesTest(fixtures.RemovesEvents, fixtures.TablesTest):
 
         eq_(connection.execute(table.select()).all(), [(1, 1), (2, 2), (3, 3)])
 
-    def test_insert_returning_values(self, connection):
+    @testing.variation("preserve_rowcount", [True, False])
+    def test_insert_returning_values(self, connection, preserve_rowcount):
         t = self.tables.data
 
         conn = connection
@@ -797,7 +797,14 @@ class InsertManyValuesTest(fixtures.RemovesEvents, fixtures.TablesTest):
             {"x": "x%d" % i, "y": "y%d" % i}
             for i in range(1, page_size * 2 + 27)
         ]
-        result = conn.execute(t.insert().returning(t.c.x, t.c.y), data)
+        if preserve_rowcount:
+            eo = {"preserve_rowcount": True}
+        else:
+            eo = {}
+
+        result = conn.execute(
+            t.insert().returning(t.c.x, t.c.y), data, execution_options=eo
+        )
 
         eq_([tup[0] for tup in result.cursor.description], ["x", "y"])
         eq_(result.keys(), ["x", "y"])
@@ -815,6 +822,9 @@ class InsertManyValuesTest(fixtures.RemovesEvents, fixtures.TablesTest):
         # assert result.closed
         assert result.cursor is None
 
+        if preserve_rowcount:
+            eq_(result.rowcount, len(data))
+
     def test_insert_returning_preexecute_pk(self, metadata, connection):
         counter = itertools.count(1)
 
@@ -1037,10 +1047,14 @@ class InsertManyValuesTest(fixtures.RemovesEvents, fixtures.TablesTest):
 
         eq_(result.all(), [("p1_p1", "y1"), ("p2_p2", "y2")])
 
-    def test_insert_returning_defaults(self, connection):
+    @testing.variation("preserve_rowcount", [True, False])
+    def test_insert_returning_defaults(self, connection, preserve_rowcount):
         t = self.tables.data
 
-        conn = connection
+        if preserve_rowcount:
+            conn = connection.execution_options(preserve_rowcount=True)
+        else:
+            conn = connection
 
         result = conn.execute(t.insert(), {"x": "x0", "y": "y0"})
         first_pk = result.inserted_primary_key[0]
@@ -1055,6 +1069,9 @@ class InsertManyValuesTest(fixtures.RemovesEvents, fixtures.TablesTest):
             [(pk, 5) for pk in range(1 + first_pk, total_rows + first_pk)],
         )
 
+        if preserve_rowcount:
+            eq_(result.rowcount, total_rows - 1)  # range starts from 1
+
     def test_insert_return_pks_default_values(self, connection):
         """test sending multiple, empty rows into an INSERT and getting primary
         key values back.
@@ -1445,6 +1462,7 @@ class IMVSentinelTest(fixtures.TestBase):
         (ARRAY(Integer()), testing.requires.array_type),
         DateTime(),
         Uuid(),
+        Uuid(native_uuid=False),
         argnames="datatype",
     )
     def test_inserts_w_all_nulls(
@@ -1766,9 +1784,11 @@ class IMVSentinelTest(fixtures.TestBase):
             Column(
                 "id",
                 Uuid(),
-                server_default=func.gen_random_uuid()
-                if default_type.server_side
-                else None,
+                server_default=(
+                    func.gen_random_uuid()
+                    if default_type.server_side
+                    else None
+                ),
                 default=uuid.uuid4 if default_type.client_side else None,
                 primary_key=True,
                 insert_sentinel=bool(add_insert_sentinel),
@@ -1987,6 +2007,8 @@ class IMVSentinelTest(fixtures.TestBase):
         "return_type", ["include_sentinel", "default_only", "return_defaults"]
     )
     @testing.variation("add_sentinel_flag_to_col", [True, False])
+    @testing.variation("native_uuid", [True, False])
+    @testing.variation("as_uuid", [True, False])
     def test_sentinel_on_non_autoinc_primary_key(
         self,
         metadata,
@@ -1995,8 +2017,13 @@ class IMVSentinelTest(fixtures.TestBase):
         sort_by_parameter_order,
         randomize_returning,
         add_sentinel_flag_to_col,
+        native_uuid,
+        as_uuid,
     ):
         uuids = [uuid.uuid4() for i in range(10)]
+        if not as_uuid:
+            uuids = [str(u) for u in uuids]
+
         _some_uuids = iter(uuids)
 
         t1 = Table(
@@ -2004,7 +2031,7 @@ class IMVSentinelTest(fixtures.TestBase):
             metadata,
             Column(
                 "id",
-                Uuid(),
+                Uuid(native_uuid=bool(native_uuid), as_uuid=bool(as_uuid)),
                 default=functools.partial(next, _some_uuids),
                 primary_key=True,
                 insert_sentinel=bool(add_sentinel_flag_to_col),
@@ -2096,6 +2123,8 @@ class IMVSentinelTest(fixtures.TestBase):
         else:
             return_type.fail()
 
+    @testing.variation("native_uuid", [True, False])
+    @testing.variation("as_uuid", [True, False])
     def test_client_composite_pk(
         self,
         metadata,
@@ -2103,15 +2132,19 @@ class IMVSentinelTest(fixtures.TestBase):
         randomize_returning,
         sort_by_parameter_order,
         warn_for_downgrades,
+        native_uuid,
+        as_uuid,
     ):
         uuids = [uuid.uuid4() for i in range(10)]
+        if not as_uuid:
+            uuids = [str(u) for u in uuids]
 
         t1 = Table(
             "data",
             metadata,
             Column(
                 "id1",
-                Uuid(),
+                Uuid(as_uuid=bool(as_uuid), native_uuid=bool(native_uuid)),
                 default=functools.partial(next, iter(uuids)),
                 primary_key=True,
             ),
